=========================
View services information
=========================

As an administrative user, you can view information for OpenStack services.

#. Log in to the Dashboard and select the
   :guilabel:`admin` project from the drop-down list.

#. On the :guilabel:`Admin` tab, open the :guilabel:`System` tab
   and click the :guilabel:`System Information` category.

   View the following information on these tabs:

   * :guilabel:`Services`:
     Displays the internal name and the public OpenStack name
     for each service, the host on which the service runs,
     and whether or not the service is enabled.

   * :guilabel:`Compute Services`:
     Displays information specific to the Compute service. Both host
     and zone are listed for each service, as well as its
     activation status.

   * :guilabel:`Block Storage Services`:
     Displays information specific to the Block Storage service. Both host
     and zone are listed for each service, as well as its
     activation status.

   * :guilabel:`Network Agents`:
     Displays the network agents active within the cluster, such as L3 and
     DHCP agents, and the status of each agent.
